==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/GridSelectedKeysChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedKeysChangedEventArgsDescription } from "./GridSelectedKeysChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedKeysChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridSelectedKeysChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedKeysChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedKeysChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedKeysChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedKeysChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedKeysChangedEventArgsDescriptionMetadata.c(GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridSelectedKeysChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedKeysChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
        a.item("AddedKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
        a.item("RemovedKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
    };
    GridSelectedKeysChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedKeysChangedEventArgsDescriptionMetadata.b(a);
        a.aa("GridSelectedKeysChangedEventArgs", function () { return new GridSelectedKeysChangedEventArgsDescription(); });
        a.z("GridSelectedKeysChangedEventArgs", GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedKeysChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedKeysChangedEventArgsDescriptionMetadata, 'GridSelectedKeysChangedEventArgsDescriptionMetadata');
    GridSelectedKeysChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedKeysChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedKeysChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/GridSelectedKeysChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedKeysChangedEventArgsDescription } from "./GridSelectedKeysChangedEventArgsDescription";
/**
 * @hidden
 */
var GridSelectedKeysChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridSelectedKeysChangedEventArgsDescriptionMetadata, _super);
    function GridSelectedKeysChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridSelectedKeysChangedEventArgsDescriptionMetadata.b = function (a) {
        if (GridSelectedKeysChangedEventArgsDescriptionMetadata.a == null) {
            GridSelectedKeysChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridSelectedKeysChangedEventArgsDescriptionMetadata.c(GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(GridSelectedKeysChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedKeysChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("CurrentKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
        a.item("AddedKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
        a.item("RemovedKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
    };
    GridSelectedKeysChangedEventArgsDescriptionMetadata.d = function (a) {
        GridSelectedKeysChangedEventArgsDescriptionMetadata.b(a);
        a.ac("GridSelectedKeysChangedEventArgs", function () { return new GridSelectedKeysChangedEventArgsDescription(); });
        a.ab("GridSelectedKeysChangedEventArgs", GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
    };
    GridSelectedKeysChangedEventArgsDescriptionMetadata.$t = markType(GridSelectedKeysChangedEventArgsDescriptionMetadata, 'GridSelectedKeysChangedEventArgsDescriptionMetadata');
    GridSelectedKeysChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedKeysChangedEventArgsDescriptionMetadata;
}(Base));
export { GridSelectedKeysChangedEventArgsDescriptionMetadata };
